pub struct Gift {
pub id: GiftId,
pub config_id: Uuid,
pub sender_id: Uuid,
pub receiver_id: Uuid,
pub claimed: bool,
pub reward: Vec<CurrencyUnit>,
pub loyalty: i64,
}Fields
id: GiftIdconfig_id: Uuidsender_id: Uuidreceiver_id: Uuidclaimed: boolreward: Vec<CurrencyUnit>loyalty: i64Trait Implementations
Sourceimpl CustomType for Gift
impl CustomType for Gift
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for Gift
impl<'de> Deserialize<'de> for Gift
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Gift
impl JsonSchema for Gift
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for Gift
impl Tsify for Gift
const DECL: &'static str = "export interface Gift {\n id: GiftId;\n config_id: Uuid;\n sender_id: Uuid;\n receiver_id: Uuid;\n claimed: boolean;\n reward: CurrencyUnit[];\n loyalty: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Gift
impl StructuralPartialEq for Gift