pub struct GiftTemplate {
pub id: Uuid,
pub gift_type: GiftType,
pub price: Vec<CurrencyUnit>,
pub reward: Vec<CurrencyUnit>,
pub loyalty: i64,
}Fields
id: Uuidgift_type: GiftTypeprice: Vec<CurrencyUnit>reward: Vec<CurrencyUnit>loyalty: i64Trait Implementations
Sourceimpl Clone for GiftTemplate
impl Clone for GiftTemplate
Sourcefn clone(&self) -> GiftTemplate
fn clone(&self) -> GiftTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GiftTemplate
impl Debug for GiftTemplate
Sourceimpl<'de> Deserialize<'de> for GiftTemplate
impl<'de> Deserialize<'de> for GiftTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GiftTemplate
impl JsonSchema for GiftTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GiftTemplate
impl PartialEq for GiftTemplate
Sourceimpl Serialize for GiftTemplate
impl Serialize for GiftTemplate
Sourceimpl Tsify for GiftTemplate
impl Tsify for GiftTemplate
const DECL: &'static str = "export interface GiftTemplate {\n id: Uuid;\n gift_type: GiftType;\n price: CurrencyUnit[];\n reward: CurrencyUnit[];\n loyalty: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for GiftTemplate
impl StructuralPartialEq for GiftTemplate